#
# spec file for package festival
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           festival
Version:        2.5.0
Release:        8.9
Summary:        The Speech Synthesis System
License:        BSD-3-Clause
Group:          Productivity/Text/Convertors
URL:            http://festvox.org/festival
Source0:        http://festvox.org/packed/%{name}/2.5/%{name}-%{version}-release.tar.gz
Source1:        http://festvox.org/packed/%{name}/2.5/speech_tools-%{version}-release.tar.gz
Source2:        http://festvox.org/packed/%{name}/2.5/festlex_CMU.tar.gz
Source3:        http://festvox.org/packed/%{name}/2.5/voices/festvox_kallpc16k.tar.gz
Source4:        http://festvox.org/packed/%{name}/2.5/festlex_POSLEX.tar.gz
Source5:        sysconfig.%{name}
Source7:        http://festvox.org/packed/%{name}/2.5/voices/festvox_rablpc16k.tar.gz
# systemd unit file
Source8:        %{name}.systemd
# festival patches
Patch2:         %{name}-1.95-examples.patch
Patch3:         %{name}-text2wave-manpage.patch
Patch4:         %{name}-1.95-libdir.patch
%if 0%{?suse_version} > 1500
Patch7:         %{name}-1.95-audsp-libexec.patch
%else
Patch7:         %{name}-1.95-audsp.patch
%endif
Patch8:         %{name}-1.96-chroot.patch
# PATCH-FIX-UPSTREAM festival-no-LD_LIBRARY_PATH-extension.patch bnc#642507 vuntz@opensuse.org -- Do not change LD_LIBRARY_PATH in binaries, to avoid any risks
Patch9:         %{name}-no-LD_LIBRARY_PATH-extension.patch
# PATCH-FIX-UPSTREAM festival-safe-temp-file.patch bnc#642507 vuntz@opensuse.org -- Create temporary files in a safe way
Patch10:        %{name}-safe-temp-file.patch
# speech-tools patches
# PATCH-FIX-UPSTREAM speech_tools-undefined-operation.patch vuntz@opensuse.org -- Avoid a undefined-operation warning with gcc (sending mail upstream)
Patch11:        speech_tools-undefined-operation.patch
Patch12:        speech_tools-1.2.95-config.patch
# PATCH-FIX-UPSTREAM speech_tools-no-LD_LIBRARY_PATH-extension.patch vuntz@opensuse.org -- Do not change LD_LIBRARY_PATH in binaries, to avoid any risks
Patch17:        speech_tools-no-LD_LIBRARY_PATH-extension.patch
Patch18:        speech_tools-remove-errneous-decl.patch
Patch19:        speech_tools-null-fragile.patch
Patch20:        festival-null-fragile.patch
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd

%description
Festival is a multilingual speech synthesis system developed at CSTR.
It offers a full text-to-speech system with various APIs as well as an
environment for development and research of speech synthesis
techniques. It is written in C++ and has a Scheme-based command
interpreter for general control.

%package devel
Summary:        Development Package for Festival
License:        MIT
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
Files needed for developing software that uses Festival.

%prep
%setup -q -b 1 -b 2 -b 3 -b 4 -b 7 -n %{name}
%patch2 -p1
%patch3 -p1
%patch4
%patch7
%patch8
%patch9 -p1
%patch10 -p1
cd ../speech_tools
%patch11 -p1
%patch12
%patch17 -p1
%patch18 -p1
%patch19 -p1
cd ../festival
%patch20 -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
# configure festival
%configure
# configure speech tools
cp config.guess config.sub ../speech_tools
cd ../speech_tools
%configure
  # -fPIC 'cause we're building shared libraries and it doesn't hurt
  # -fno-strict-aliasing because of a couple of warnings about code
  #   problems; if $RPM_OPT_FLAGS contains -O2 or above, this puts
  #   it back. Once that problem is gone upstream, remove this for
  #   better optimization.
  make \
    CFLAGS="%{optflags} -fPIC -fno-strict-aliasing" \
    CXXFLAGS="%{optflags} -fPIC -fno-strict-aliasing"
cd ../%{name}
make \
  FTLIBDIR="%{_datadir}/festival" \
  CFLAGS="%{optflags} -fPIC" \
  CXXFLAGS="%{optflags} -fPIC"
make %{?_smp_mflags} doc

%install
%make_install
cd ../speech_tools
%make_install
cd ../%{name}
# install binaries
install -D bin/text2wave %{buildroot}%{_bindir}/text2wave
install -m 755 bin/%{name}* %{buildroot}%{_bindir}/
install -m 755 examples/saytime %{buildroot}%{_bindir}/
# install manpages
install -Dm 644 doc/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -m 644 doc/%{name}_client.1 %{buildroot}%{_mandir}/man1/
install -m 644 doc/text2wave.1 %{buildroot}%{_mandir}/man1/
# install configs
install -Dm 644 lib/%{name}.scm %{buildroot}%{_sysconfdir}/%{name}.scm
# install dictionarys
install -Dm 644 lib/dicts/cmu/cmudict-0.4.out %{buildroot}%{_datadir}/%{name}/dicts/cmu/cmudict-0.4.out
install -m 644 lib/dicts/cmu/*.scm %{buildroot}%{_datadir}/%{name}/dicts/cmu/
install -m 644 lib/dicts/wsj.wp39.poslexR %{buildroot}%{_datadir}/%{name}/dicts/
install -m 644 lib/dicts/wsj.wp39.tri.ngrambin %{buildroot}%{_datadir}/%{name}/dicts/
# install voices
mkdir -p %{buildroot}%{_datadir}/%{name}/voices/english/{kal_diphone,rab_diphone}/{group,festvox}
cp lib/voices/english/kal_diphone/group/* %{buildroot}%{_datadir}/%{name}/voices/english/kal_diphone/group/
cp lib/voices/english/kal_diphone/festvox/*.scm %{buildroot}%{_datadir}/%{name}/voices/english/kal_diphone/festvox
cp lib/voices/english/rab_diphone/group/* %{buildroot}%{_datadir}/%{name}/voices/english/rab_diphone/group/
cp lib/voices/english/rab_diphone/festvox/*.scm %{buildroot}%{_datadir}/%{name}/voices/english/rab_diphone/festvox
# install data
cp lib/*.scm %{buildroot}%{_datadir}/%{name}/
cp lib/*.ngrambin %{buildroot}%{_datadir}/%{name}/
cp lib/*.gram %{buildroot}%{_datadir}/%{name}/
cp lib/*.el %{buildroot}%{_datadir}/%{name}/
install -D lib%{_sysconfdir}/unknown_Linux/audsp %{buildroot}%{_libexecdir}/%{name}/audsp
# install includes
mkdir -p %{buildroot}%{_includedir}/
install -m 644 src/include/*.h %{buildroot}%{_includedir}/
cd ../speech_tools

mkdir -p %{buildroot}%{_includedir}/{instantiate,ling_class,rxp,sigpr,unix}
install -m 644 include/*h %{buildroot}%{_includedir}
install -m 644 include/instantiate/*h %{buildroot}%{_includedir}/instantiate
install -m 644 include/ling_class/*h %{buildroot}%{_includedir}/ling_class
install -m 644 include/rxp/*h %{buildroot}%{_includedir}/rxp
install -m 644 include/sigpr/*h %{buildroot}%{_includedir}/sigpr
install -m 644 include/unix/*h %{buildroot}%{_includedir}/unix
# install libs
install -Dm 644 ../%{name}/src/lib/libFestival.a  %{buildroot}/%{_libdir}/libFestival.a
install -m 644 lib/lib*.a %{buildroot}%{_libdir}
install -d %{buildroot}%{_sbindir}
ln -sf /sbin/service %{buildroot}%{_sbindir}/rc%{name}
# install systemd unit file
install -m 644 -D %{SOURCE8} %{buildroot}%{_unitdir}/%{name}.service
# installl sysconfig file
install -m 644 -D %{SOURCE5} %{buildroot}%{_fillupdir}/sysconfig.%{name}

# remove instalation instructions
rm -f %{buildroot}%{_docdir}/%{name}/INSTALL

%pre
getent group %{name} >/dev/null || %{_sbindir}/groupadd -r %{name}
getent passwd %{name} >/dev/null || \
	%{_sbindir}/useradd -r -g %{name} -s /bin/false -c "Festival daemon" \
	-d %{_datadir}/%{name}/ %{name}
%service_add_pre %{name}.service

%post
%fillup_only
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc examples/*.text examples/ex1.* examples/*.scm examples/*.dtd
%config(noreplace) %{_sysconfdir}/%{name}.scm
%{_bindir}/%{name}
%{_bindir}/%{name}_client
%{_bindir}/%{name}_server
%{_bindir}/%{name}_server_control
%{_bindir}/text2wave
%{_bindir}/saytime
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_libexecdir}/%{name}
%{_datadir}/%{name}
%{_mandir}/man1/*
%{_fillupdir}/*

%files devel
%{_includedir}/*
%{_libdir}/lib*.a

%changelog
* Mon Jul 19 2021 Yasuhiko Kamata <belphegor@belbel.or.jp>
- Added festival-1.95-audsp-libexec.patch to support new directory
  structure in Tumbleweed (/usr/libexec should be used for internal
  binary) (boo#1188227).
* Fri Sep  4 2020 Yasuhiko Kamata <belphegor@belbel.or.jp>
- Removed "rcfestival" and added almost equivalent functionality
  to systemd unit file (thanks to Franck Bui <fbui@suse.com>).
- Removed %%stop_on_removal and %%restart_on_update from .spec,
  which is not needed anymore.
* Wed Sep  2 2020 Franck Bui <fbui@suse.com>
- /var/run has been obsoleted by /run since a long time.
* Wed Sep  2 2020 Franck Bui <fbui@suse.com>
- Drop dependency on insserv-compat
  insserv-compat is going to be dropped soon or later on systems with
  systemd as init system.
  It was only needed by /usr/lib/festival/server that uses rc_status
  to pretty print the status of a command.
  Since this script is intended to be used by festival.service only
  and not called directly by users and systemd has already its own
  mechanism to report status, the use of rc_status doesn't seem to be
  useful.
  Also there's no point in using %%insserv_cleanup in %%postun as this
  package doesn't ship any sysv init script.
* Mon Aug 31 2020 Yasuhiko Kamata <belphegor@belbel.or.jp>
- Removed unnecessary and unexpected "_link".
- Updated .spec file according to the Tumbleweed's change
  (%%{_libexecdir} was changed from /usr/lib to /usr/libexec).
* Fri Jun 19 2020 Yasuhiko Kamata <belphegor@belbel.or.jp>
- Added speech_tools-null-fragile.patch and
  festival-null-fragile.patch to fix NULL dereference problem
  (EST_Item's method may be called even though "this" is NULL);
  it causes SIGSEGV in text2wave (boo#1173193).
* Sat Jun  6 2020 Yasuhiko Kamata <belphegor@belbel.or.jp>
- Added speech_tools-remove-errneous-decl.patch to fix build error
  at Tumbleweed (Thanks to github's commit:
  https://github.com/festvox/speech_tools/pull/21).
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
- Run spec-cleaner
* Mon Dec 17 2018 Jan Engelhardt <jengelh@inai.de>
- Do not ignore errors from useradd/groupadd.
* Sat Nov 24 2018 belphegor@belbel.or.jp
- Update to version 2.5.0
  * This update includes a solution for boo#1116808.
  * But upstream seems not to provide a detailed changelog..
- Changed upstream URL to http://festvox.org/festival/,
  original URL http://www.cstr.ed.ac.uk/projects/festival/ seemed
  not to be maintained anymore.
* Thu Nov 15 2018 belphegor@belbel.or.jp
- Removed sysvinit support according to the boo#1116010.
  * Added systemd unit file
  * Moved rcfestival to /usr/lib/festival/server
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Mar 14 2017 dimstar@opensuse.org
- Add PreReq: insserv-compat. insserv is no longer part of a
  standard SUSE setup, since we have long switched to systemd.
* Thu Feb 12 2015 p.drouand@gmail.com
- Update to version 2.4
  * Updated HTS and CG engines
  * Support for newer compilers
  * Bug fixes galore.
  * Backwards compatibility with Festival 1.4.3
  * English (British and American), Spanish and Welsh text to speech
  * Externally configurable language independent modules:
  - phonesets
  - lexicons
  - letter-to-sound rules
  - tokenizing
  - part of speech tagging
  - intonation and duration
  * Waveform synthesizers:
  - Multisyn unit selection engine
  - HTS parametric synthesis engine
  - Clustergen parametric synthesis engine
  - Clunits unit selection engine
  - diphone based: residual excited LPC (and PSOLA not for distribution)
  - MBROLA database support.
  - distributed under a free X11-type licence
  * Portable (Unix) distribution
  * On-line documentation
  * SABLE markup, Emacs, client/server, scripting interfaces.
- Update speech_tools-undefined-operation.patch
- Remove speech_tools-gcc47.patch; merged on upstream release
- Add festvox_rablpc16k.tar.gz; new upstream english festvox
* Sun Jul 13 2014 devel.openSUSE.org@gmail.com
- Spec-file cleanup
* Tue Apr  9 2013 schwab@suse.de
- Update config.guess/sub for speech_tools
* Mon Nov 19 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Sat Mar 17 2012 dimstar@opensuse.org
- Add speech_tools-gcc47.patch: Fix build with gcc 4.7.
* Mon Jun 27 2011 vuntz@opensuse.org
- Update to version 2.1:
  + Integrated and updated support for HTS, Clustergen, Multisyn
    and Clunits voices.
  + Build fixes for newer gcc.
  + Bug fixes galore.
- Drop various patches that were needed to fix build issues
  (generally caused by recent gcc): festival-1.95-gcc4.patch,
  festival-1.96.patch, speech_tools-1.2.95-gcc4.patch,
  speech_tools-1.2.95-gcc41.patch,
  speech_tools-1.2.95-returnvalue.patch,
  speech_tools-1.2.96-beta-const.patch,
  speech_tools-1.2.96-beta.patch.
- Rebase festival-no-LD_LIBRARY_PATH-extension.patch and
  speech_tools-no-LD_LIBRARY_PATH-extension.patch, and change them
  to not remove empty files (which introduces errors during the
  build) by keeping an empty line in those files.
- Add speech_tools-undefined-operation.patch, which contains the
  only interesting bit left from speech_tools-1.2.95-gcc41.patch.
* Thu Sep 30 2010 vuntz@opensuse.org
- Add festival-safe-temp-file.patch: do not use the PID of the
  process to create a temporary file. Mentioned in bnc#642507.
* Wed Sep 29 2010 vuntz@opensuse.org
- Add festival-no-LD_LIBRARY_PATH-extension.patch and
  speech_tools-no-LD_LIBRARY_PATH-extension.patch: do not change
  LD_LIBRARY_PATH to include a directory that can be used by
  malicious users. Fix bnc#642507.
* Mon Jun  8 2009 ro@suse.de
- Add speech_tools-1.2.96-beta-const.patch to fix build: strchr
  return value changed from char* to const char*
* Mon Jan 21 2008 mskibbe@suse.de
- fix build problems with new gcc
* Thu Sep 20 2007 hvogel@suse.de
- get rid of usermod %%pre call
- add group/useradd to prereq
* Fri Aug 31 2007 mskibbe@suse.de
- Bug 294691 - VUL-0: Festival: Privilege elevation
* Mon Aug 27 2007 mskibbe@suse.de
- fix 64 bit build problem
* Mon Jul 30 2007 mskibbe@suse.de
- update speech_tools to version 1.96-beta which
  o fix a lot of bugs
  o includes speech_tools-1.2.95-includes.patch
  o fix VUL-0: Festival: Privilege elevation (#294691)
* Fri Mar 30 2007 ro@suse.de
- added ncurses-devel to buildreq
* Mon Jan 29 2007 mskibbe@suse.de
- festival-devel packages is incomplete (#230697)
* Tue Oct 31 2006 meissner@suse.de
- use RPM_OPT_FLAGS
* Wed Sep 13 2006 mskibbe@suse.de
- update to version 1.96 which
  o compiles with gcc 4.0
  o contains a lot of little bug fixes
* Tue Jul 18 2006 mskibbe@suse.de
- fix a problem that audsp cannot be open (#190100)
* Tue Mar 21 2006 hvogel@suse.de
- define outidx [#158757]
* Wed Mar  8 2006 cthiel@suse.de
- PreReq %%fillup_prereq, to make %%post scripts work
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 hvogel@suse.de
- remove cmudict_extensions.scm because of license issues.
- add init script for festival in server mode by Andreas Schneider.
  [#143397]
- default allow connections from localhost for gnome-speech.
  Patch by Fernando Herrera. [#144082]
* Wed Jan 11 2006 hvogel@suse.de
- split devel subpackage
* Wed Dec  7 2005 rguenther@suse.de
- fix operator overloads returning references to temporary
  objects
* Thu Nov  3 2005 rguenther@suse.de
- fix gcc 4.1 compilation problems
- build with -ffriend-injection
* Fri Sep  2 2005 hvogel@suse.de
- fix man page permissions [#114849]
* Wed Aug 31 2005 hvogel@suse.de
- add festival.el for emacs [#114380]
* Fri Aug 26 2005 hvogel@suse.de
- fix libdir path [#113090]
* Tue May 24 2005 hvogel@suse.de
- fix missing class types
* Thu May 19 2005 hvogel@suse.de
- add manpages
- get rid of -Wall for g++
- use optflags for gcc
- package the saytime script
- simplify install section
- general sepcfile cleanup
- fix some more include warnings
* Wed May 18 2005 hvogel@suse.de
- Update to version 1.95
- fix the rest
* Fri May 13 2005 yxu@suse.de
- partly fixed for GCC4
- still problems with function templates left
* Mon Jan 10 2005 adrian@suse.de
- install libraries and header files
- do compile with -fPIC
- do not build as root anymore
* Mon Apr 19 2004 meissner@suse.de
- fixed aliasing problem.
* Sat Mar 20 2004 meissner@suse.de
- fixed paths to sample files #36618
* Mon Mar 15 2004 sbrabec@suse.cz
- Removed obsolete mandir and infodir.
* Tue Feb 24 2004 hhetter@suse.de
- include festival license in %%doc
* Thu Feb 19 2004 hhetter@suse.de
- initial SUSE package
